developerscripttools.CleanScript
================================

.. abjad-lineage:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript

.. autoclass:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.alias
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.argument_parser
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.formatted_help
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.formatted_usage
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.formatted_version
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.long_description
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.program_name
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.scripting_group
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.short_description
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.storage_format
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.version
   :noindex:

Methods
-------

.. automethod:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.process_args
   :noindex:

.. automethod:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.setup_argument_parser
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.__call__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.__eq__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.__ge__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.__gt__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.__le__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.__lt__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.__ne__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.__repr__
   :noindex:
